@@ -432,14 +432,17 @@ class Model:
             if variable.name in data:
                 variable.value = data[variable.name]
             elif 'table' in data:
-                n = -1
                 for table in data['table']:
-                    n = n + 1
                     if variable.name in table:
-                        if n == 0:
-                            variable.value = table[variable.name]
-                        else:
-                            self.__variables.append(Variable(variable.name,varible.row+n,variable.column,table[variable.name]))
+                        variable.value = table[variable.name]
+                            
+        for variable in self.variables:
+            if 'table' in data:
+                n=0
+                for table in data['table']:
+                    if variable.name in table:
+                        n=n+1
+                        self.__variables.append(Variable(variable.name,varible.row+n,variable.column,table[variable.name]))
         return None
 
     def past_in_worksheet(self,worksheet):
